Theory of Operation
===================

.. note::

   This section explains both why an application or framework might
   publish events, and various ways the integrator might configure
   the subscribers to achieve different goals.

Outline
-------

- Events as decoupling mechanism.

  - Injecting policy into reusable applications.

  - Extending frameworks.

- Event dispatch strategies

  - Type-based dispatch, as used in ZCA

  - Attribute-based / key-based dispatch
